###
### Trends in STAR v5.0
###

rm(list=ls())			
options(scipen=999)
library(sandwich)
library(car)

# READ DATA (note LTGlobal 1979:1-1980:12 = UAH)
star=read.csv("STAR.csv",sep=",",header=TRUE)
attach(star)

# GENERATE MODEL TERMS
date.c = paste(year,month,sep=".")
date.n = year+(month-1)/12
N = length(year)
t = c(1:N)
startyear = 1989
endyear   = 2012
d1 = (year > startyear)
d2 = (year > endyear)
n1 = N-sum(d1)+1
n2 = N-sum(d2)+1
time.dummy = d1
s = n2-n1+1

# TABLE FOR TREND DIFFERENCES
Table1 = matrix(0,s,4)
colnames(Table1)=c("LT-Global","MT-Global","TTT-Global","TTT-Tropics")
rownames(Table1)=c(date.c[n1:n2])

# TABLE FOR P-values
Table2 = matrix(0,s,4)
colnames(Table2)=c("LT-Global","MT-Global","TTT-Global","TTT-Tropics")
rownames(Table2)=c(date.c[n1:n2])


for (i in n1:n2) {
  time.dummy[i] = 0
  d=time.dummy
  dt = d*t

  # LT-Global
  reg = lm(LTGlobal ~ t + dt +d)
  beta_d = reg$coef[3]
  Table1[i+1-n1,1] = 120*beta_d
  vv = NeweyWest(reg) 
  Table2[i+1-n1,1] = linearHypothesis(reg,c("dt=0"),vcov=vv)$Pr[2]

  # MT-Global
  reg = lm(MTGlobal ~ t + dt +d)
  beta_d = reg$coef[3]
  Table1[i+1-n1,2] = 120*beta_d
  vv = NeweyWest(reg) 
  Table2[i+1-n1,2] = linearHypothesis(reg,c("dt=0"),vcov=vv)$Pr[2]
  
  # TTT-Global
  reg = lm(TTTGlobal ~ t + dt +d)
  beta_d = reg$coef[3]
  Table1[i+1-n1,3] = 120*beta_d
  vv = NeweyWest(reg) 
  Table2[i+1-n1,3] = linearHypothesis(reg,c("dt=0"),vcov=vv)$Pr[2]
  
  # TTT-Tropics
  reg = lm(TTTTropics ~ t + dt +d)
  beta_d = reg$coef[3]
  Table1[i+1-n1,4] = 120*beta_d
  vv = NeweyWest(reg) 
  Table2[i+1-n1,4] = linearHypothesis(reg,c("dt=0"),vcov=vv)$Pr[2]
  
      }

# PLOT P-Values - TTT
par(xaxt="s",yaxt="s")
plot(Table2[,3] ~ date.n[n1:n2],type="l",lwd=2,ylim=c(-0,1.2), ylab="P-value", xlab="",col="darkgreen")
par(new=TRUE, xaxt="n", yaxt="n")
plot(Table2[,4] ~ date.n[n1:n2],type="l",lwd=2,ylim=c(-0,1.2), ylab="", xlab="",col="red")
legend("top", legend=c("TTT-Global", "TTT-Tropics"), text.col=c("darkgreen","red"),ncol=2,bty="n")
abline(h=0.05,  lty=2)

# PLOT P-Values - LT,MT
plotall=1
if(plotall == 1) {
plot(Table2[,1] ~ date.n[n1:n2],type="l",lwd=2,ylim=c(-0,1.2), ylab="P-value", xlab="",col="orange")
par(new=TRUE, xaxt="s", yaxt="s")
plot(Table2[,2] ~ date.n[n1:n2],type="l",lwd=2,ylim=c(-0,1.2), ylab="", xlab="",col="dodgerblue")
par(new=TRUE, xaxt="n", yaxt="n")
legend("top", legend=c("LT-Global","MT-Global"), text.col=c("orange","dodgerblue"),ncol=4,bty="n")
abline(h=0.05,  lty=2)
}

# PLOT TREND
plottrend = 1
total_trend = lm(MTGlobal~t)
total_beta = round(120*total_trend$coef[2],3)
fitted = total_trend$fitted.values
if(plottrend == 1) {
  par(xaxt="s",yaxt="s")
  plot(MTGlobal~date.n,type="l", ylim=c(-1,1), ylab="deg C",xlab="")
  abline(h=0)
  text(1990,0.8,"MT-Global NOAA v5.0")
  par(new=TRUE,xaxt="n")
  plot(fitted~date.n,type="l",col="blue", ylim=c(-1,1), ylab="", xlab="")
} 

